@@ -1,3 +1,4 @@
+import logging
 from copy import deepcopy
 from datetime import datetime, timedelta
 from typing import Any, Dict, List, Optional
@@ -30,10 +31,12 @@ def date_parse(date_str: str) -> Optional[datetime]:
         return None
 
     try:
-        return parser.isoparse(date_str)
-    except Exception as e:
-        print("issue parsing {date_str} - {e}")
         return dateparser.parse(date_str)
+    except Exception as e:
+        logging.getLogger("").exception(
+            f"Date input of {date_str} unable to be parsed by default parser. Falling back to default parser: {e}."
+        )
+        return parser.isoparse(date_str)
 
 
 def to_date(date_str: str, format_str: str = "%Y%m%d") -> datetime:
